<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE stylesheet [
	<!ENTITY nbsp  "&#160;" >
]>
<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:audit="urn:linux:audit:ausearch"
	xmlns:str="http://exslt.org/strings"
	extension-element-prefixes="str"
	version="1.0">
	
	<!-- Used to see if a particular record is part of a group -->
	<xsl:key name="record" match="audit:ausearch/audit:Event/audit:record" use="@timestamp"/>
	
	<xsl:output method="html"
		doctype-system="http://www.w3.org/TR/html4/strict.dtd"
		doctype-public="-/W3C//DTD HTML 4.01//EN"
		indent="yes"
		encoding="UTF-8"
		omit-xml-declaration="yes"/>

	<xsl:strip-space elements="*"/>
	
	<xsl:template match="text()" />
	
	<xsl:template match="audit:ausearch">
		<html>
			<head>
				<xsl:element name="title">
					<xsl:text>Audit report for </xsl:text>
					<xsl:value-of select="@hostname"/>
				</xsl:element>
				<meta http-equiv="Content-type" content="text/html;charset=UTF-8" />
				<xsl:element name="meta">
					<xsl:attribute name="name">hostname</xsl:attribute>
					<xsl:attribute name="content"><xsl:value-of select="@hostname"/></xsl:attribute>
				</xsl:element>
				<xsl:element name="meta">
					<xsl:attribute name="name">generated</xsl:attribute>
					<xsl:attribute name="content"><xsl:value-of select="@generated"/></xsl:attribute>
				</xsl:element>
				<xsl:element name="meta">
					<xsl:attribute name="name">generator</xsl:attribute>
					<xsl:attribute name="content"><xsl:value-of select="@generator"/></xsl:attribute>
				</xsl:element>
				
				<xsl:comment>See datatables.net for sorting and filtering JavaScript libraries</xsl:comment>
				
				<!-- DataTables CSS -->
				<link rel="stylesheet" type="text/css" href="http://ajax.aspnetcdn.com/ajax/jquery.dataTables/1.9.4/css/jquery.dataTables.css" />
				
<style type="text/css">
th {
	font: bold 12px Verdana, Arial, Helvetica, sans-serif;
	letter-spacing: 2px;
	text-transform: uppercase;
	text-align: left;
}

table {
	font: 10px Verdana, Arial, Helvetica, sans-serif;
}

.dataTables_filter {
	font: 10px Verdana, Arial, Helvetica,sans-serif;
	padding-bottom: 10px;
}

.dataTables_info {
	font: 10px Verdana, Arial, Helvetica,sans-serif;
	padding-top: 10px;
	padding-bottom: 10px;
}

td.fail {
	background: #7A0000 !important;
	color: white !important;
}

td.group {
	border-left: solid black;
	border-right: solid black;
}
</style>
				
				<!-- jQuery -->
				<script type="text/javascript" charset="utf8" src="http://ajax.aspnetcdn.com/ajax/jQuery/jquery-1.8.2.min.js" />
 				
				<!-- DataTables -->
				<script type="text/javascript" charset="utf8" src="http://ajax.aspnetcdn.com/ajax/jquery.dataTables/1.9.4/jquery.dataTables.min.js" />
			</head>
			<body>
				<xsl:element name="h1">
					<xsl:text>Audit report for </xsl:text>
					<xsl:value-of select="@hostname"/>
					<xsl:text> generated on </xsl:text>
					<xsl:value-of select="@generated"/>
				</xsl:element>
				<table border="1" cellpadding="5" id="atable">
					<thead>
						<tr>
							<th title="Event">Ev</th><th>Node</th><th>Timestamp</th><th>Type</th>
							<th>uid</th><th>pid</th><th>exe</th><th>Result</th><th>Message</th>
						</tr>
					</thead>
					<tbody>
						<xsl:apply-templates/>
					</tbody>
				</table>
				
				<script type="text/javascript">
				$(document).ready(function(){
					$('#atable').dataTable({
						"bPaginate": false,
        					"bLengthChange": false,
        					"bFilter": true,
        					"bSort": true,
        					"bInfo": true,
        					"bProcessing": true
        				});
				});
				</script>
			</body>
		</html>
	</xsl:template>
	
	<xsl:template match="/audit:ausearch/audit:Event">
		<xsl:apply-templates select="audit:record"/>
	</xsl:template>
	
	<xsl:template name="result">
		<xsl:param name="value"/>
		
		<xsl:element name="td">
			<xsl:attribute name="class">
				<xsl:choose>
					<xsl:when test="contains($value, 'fail') or contains($value, 'denied') or $value = 'no'">fail</xsl:when>
				</xsl:choose>
			</xsl:attribute>
			<xsl:value-of select="$value"/>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="audit:record">
		<tr>
			<xsl:element name="td">
				<xsl:if test="count(key('record', @timestamp)) > 1">
					<xsl:attribute name="class">group</xsl:attribute>
				</xsl:if>
				<xsl:number count="audit:Event"/>
			</xsl:element>
			<td><xsl:value-of select="@node"/></td>
			<!-- Use EXSLT instead of XSLT 2, due to limitation in libxslt -->
			<td><xsl:value-of select="str:replace(@timestamp, ' ', '&nbsp;')"/></td>
			<td><xsl:value-of select="@type"/></td>
			<td><xsl:value-of select="child::audit:uid"/></td>
			<td><xsl:value-of select="child::audit:pid"/></td>
			<td><xsl:value-of select="descendant::audit:exe"/></td>

			<!-- result may be in the main values or within the msg -->
			<xsl:choose>
				<xsl:when test="child::audit:res">
					<xsl:call-template name="result">
						<xsl:with-param name="value"><xsl:value-of select="child::audit:res"/></xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="child::audit:success">
					<xsl:call-template name="result">
						<xsl:with-param name="value"><xsl:value-of select="child::audit:success"/></xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="descendant::audit:res">
					<xsl:call-template name="result">
						<xsl:with-param name="value"><xsl:value-of select="descendant::audit:res"/></xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="contains(child::audit:info, 'denied')">
					<xsl:call-template name="result">
						<xsl:with-param name="value">denied</xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="result"/>
				</xsl:otherwise>
			</xsl:choose>
			<td><xsl:apply-templates/></td>
		</tr>
	</xsl:template>
	
	<xsl:template match="audit:msg">msg='<xsl:apply-templates/>'</xsl:template>
	
	<xsl:template match="*">
		<xsl:if test="name() != 'info'">
			<xsl:value-of select="name()"/>
			<xsl:if test="@status"><xsl:text> (</xsl:text><xsl:value-of select="@status"/>)</xsl:if>
			<xsl:text>=</xsl:text>
		</xsl:if>
		<xsl:value-of select="."/>
		
		<xsl:if test="following-sibling::*"><xsl:text> </xsl:text></xsl:if>
	</xsl:template>
</xsl:stylesheet>
